aboutsummaryrefslogtreecommitdiffstats
path: root/core/interfaces.go
diff options
context:
space:
mode:
authorMission Liao <mission.liao@dexon.org>2018-09-25 17:19:00 +0800
committerWei-Ning Huang <aitjcize@gmail.com>2018-09-25 17:19:00 +0800
commitd844c339a128322dff180a6ccc6e6b241e917546 (patch)
tree53d9b1add43a5e242a51a097be8b55048eefa1c2 /core/interfaces.go
parent6c8d26d2e797e8420fc3de4b15e4c556f968aba0 (diff)
downloadtangerine-consensus-d844c339a128322dff180a6ccc6e6b241e917546.tar
tangerine-consensus-d844c339a128322dff180a6ccc6e6b241e917546.tar.gz
tangerine-consensus-d844c339a128322dff180a6ccc6e6b241e917546.tar.bz2
tangerine-consensus-d844c339a128322dff180a6ccc6e6b241e917546.tar.lz
tangerine-consensus-d844c339a128322dff180a6ccc6e6b241e917546.tar.xz
tangerine-consensus-d844c339a128322dff180a6ccc6e6b241e917546.tar.zst
tangerine-consensus-d844c339a128322dff180a6ccc6e6b241e917546.zip
Fix naming of methods (#134)
- BlockDeliver -> BlockDelivered - TotalOrderingDeliver -> TotalOrderingDelivered - WitnessAckDeliver -> WitnessAckDelivered - VerifyPayload -> VerifyPayloads
Diffstat (limited to 'core/interfaces.go')
-rw-r--r--core/interfaces.go16
1 files changed, 8 insertions, 8 deletions
diff --git a/core/interfaces.go b/core/interfaces.go
index 03caa63..4e0b4cc 100644
--- a/core/interfaces.go
+++ b/core/interfaces.go
@@ -30,18 +30,18 @@ type Application interface {
// PreparePayload is called when consensus core is preparing a block.
PreparePayload(position types.Position) []byte
- // VerifyPayloads verifies if the payloads are valid.
- VerifyPayloads(payloads []byte) bool
+ // VerifyPayload verifies if the payloads are valid.
+ VerifyPayload(payloads []byte) bool
- // BlockDeliver is called when a block is add to the compaction chain.
- BlockDeliver(block types.Block)
+ // BlockDelivered is called when a block is add to the compaction chain.
+ BlockDelivered(block types.Block)
// BlockProcessedChan returns a channel to receive the block hashes that have
// finished processing by the application.
BlockProcessedChan() <-chan types.WitnessResult
- // WitnessAckDeliver is called when a witness ack is created.
- WitnessAckDeliver(witnessAck *types.WitnessAck)
+ // WitnessAckDelivered is called when a witness ack is created.
+ WitnessAckDelivered(witnessAck *types.WitnessAck)
}
// Debug describes the application interface that requires
@@ -53,9 +53,9 @@ type Debug interface {
// StronglyAcked is called when a block is strongly acked.
StronglyAcked(blockHash common.Hash)
// TotalOrderingDeliver is called when the total ordering algorithm deliver
// a set of block.
- TotalOrderingDeliver(blockHashes common.Hashes, early bool)
+ TotalOrderingDelivered(blockHashes common.Hashes, early bool)
}
// Network describs the network interface that interacts with DEXON consensus
@@ -53,9 +53,9 @@ type Debug interface {
// StronglyAcked is called when a block is strongly acked.
StronglyAcked(blockHash common.Hash)
- // TotalOrderingDeliver is called when the total ordering algorithm deliver
+ // TotalOrderingDelivered is called when the total ordering algorithm deliver
// a set of block.